# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.22.5~ea323d8',
    built_at='2025-10-13 13:50:46Z',
    sha='ea323d813d62b879396b32deffba7410d4f3d67f',
    branch='HEAD',
    tag='v4.22.5',
)
